@@ -6,14 +6,9 @@
 #' @export
 #'
 #' @examples
-#' \donttest{
-#' \dontrun{
-#' censo_borrar_base()
-#' }
-#' }
+#' \dontrun{ censo_borrar_base() }
 censo_borrar_base <- function() {
   suppressWarnings(censo_desconectar_base())
   try(unlink(censo_path(), recursive = TRUE))
   update_censo_pane()
-  censo_panel()
 }
